=============
Grocery Store
=============

This example aims to demonstrate a wide breadth of desmod features.

.. graphviz:: workspace/hier.dot

.. literalinclude:: grocery.py

Running the simulation with the default configuration produces the
following ``result.json``:

.. literalinclude:: workspace/result.json
